@@ -1,7 +1,5 @@
 from dataclasses import dataclass
 
-from . import antidot, lattice
-
 
 @dataclass
 class parms:
@@ -24,27 +22,27 @@ class parms:
     aex: str = "13e-12"
     ku1: str = "453195"
     anisu: str = "vector(0,0,1)"
-    alpha: str = "0.015"
+    alpha: str = "1e-7"
     gammall: str = "187e9"
     # Static
     m: str = "uniform(1e-5, 1e-5, 1)"
     angle: str = "0.0001"
     B0: str = "0.223"
-    maxerr_s: str = "4e-6"
-    minimizerstop: str = "1e-8"
-    relaxtorquethreshold: str = "1e-6"
+    maxerr_s: str = "4e-5"
+    minimizerstop: str = "1e-7"
+    relaxtorquethreshold: str = "1e-5"
     # Dynamics
     mindt: str = "1e-14"
     maxdt: str = "1.42e-12"
     maxerr_d: str = "1e-7"
     solver: int = 5
-    amps: str = "9e-2"
+    amps: str = "5e-3"
     f_cut: str = "20e9"
     t0: str = "t + 10/f_cut"
     t_sampl: str = "0.5 / (f_cut * 1.5)"
     Bmask: str = ""
     autosave: str = "autosave(m,t_sampl)"
-    trun: str = "1500"
+    trun: str = "500"
     # Overrides
     mesh: str = ""
     material: str = ""
